summaryrefslogtreecommitdiffstats
path: root/kig/misc/kiginputdialog.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commiteb570158698cf61dad4f77d950ef908160f6c3cc (patch)
tree649bf182bcf0a20bed5035d25ffd77de5aee138a /kig/misc/kiginputdialog.h
parentd8762de95349dc6edaa34db9bf699b367c1af6b1 (diff)
downloadtdeedu-eb570158698cf61dad4f77d950ef908160f6c3cc.tar.gz
tdeedu-eb570158698cf61dad4f77d950ef908160f6c3cc.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeedu@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kig/misc/kiginputdialog.h')
-rw-r--r--kig/misc/kiginputdialog.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kig/misc/kiginputdialog.h b/kig/misc/kiginputdialog.h
index 60f2ba54..f11d2665 100644
--- a/kig/misc/kiginputdialog.h
+++ b/kig/misc/kiginputdialog.h
@@ -46,9 +46,9 @@ Q_OBJECT
public:
private:
- KigInputDialog( const TQString& caption, const TQString& label, TQWidget* tqparent,
+ KigInputDialog( const TQString& caption, const TQString& label, TQWidget* parent,
const KigDocument& doc, Coordinate* c1, Coordinate* c2 );
- KigInputDialog( TQWidget* tqparent, const Goniometry& g );
+ KigInputDialog( TQWidget* parent, const Goniometry& g );
virtual void keyPressEvent( TQKeyEvent* e );
@@ -70,7 +70,7 @@ public:
*
* \param caption caption of the dialog
* \param label text of the label of the dialog
* \param tqparent tqparent of the dialog widget
* \param ok it will be set to true if the user pressed Ok after inserting a
* well-formatted Coordinate
* \param doc the actual Kig document
@@ -80,14 +80,14 @@ public:
* displayed as initial value of the correspondenting text edit
*/
static void getCoordinate( const TQString& caption, const TQString& label,
- TQWidget* tqparent, bool* ok, const KigDocument& doc, Coordinate* cvalue );
+ TQWidget* parent, bool* ok, const KigDocument& doc, Coordinate* cvalue );
/**
* Static convenience function to get two Coordinates at once from the user.
*
* \param caption caption of the dialog
* \param label text of the label of the dialog
* \param tqparent tqparent of the dialog widget
* \param ok it will be set to true if the user pressed Ok after inserting
* well-formatted Coordinates
* \param doc the actual Kig document
@@ -103,14 +103,14 @@ public:
* the text edit representing the second Coordinate.
*/
static void getTwoCoordinates( const TQString& caption, const TQString& label,
- TQWidget* tqparent, bool* ok, const KigDocument& doc, Coordinate* cvalue,
+ TQWidget* parent, bool* ok, const KigDocument& doc, Coordinate* cvalue,
Coordinate* cvalue2 );
/**
* Static convenience function to get an angle incapsulated in a Goniometry
* class.
*
* \param tqparent tqparent of the dialog widget
* \param ok it will be set to true if the user pressed Ok after inserting a
* well-formatted angle
* \param g the Goniometry class containing the original angle we are going
@@ -118,7 +118,7 @@ public:
*
* \return a Goniometry class containing the new angle
*/
- static Goniometry getAngle( TQWidget* tqparent, bool* ok, const Goniometry& g );
+ static Goniometry getAngle( TQWidget* parent, bool* ok, const Goniometry& g );
};
#endif
@@ -70,7 +70,7 @@ public:
* \param caption caption of the dialog
* \param label text of the label of the dialog
- * \param tqparent tqparent of the dialog widget
+ * \param parent parent of the dialog widget
* \param ok it will be set to true if the user pressed Ok after inserting a
* well-formatted Coordinate
@@ -80,14 +80,14 @@ public:
* \param caption caption of the dialog
* \param label text of the label of the dialog
- * \param tqparent tqparent of the dialog widget
+ * \param parent parent of the dialog widget
* \param ok it will be set to true if the user pressed Ok after inserting
* well-formatted Coordinates
@@ -103,14 +103,14 @@ public:
* class.
*
- * \param tqparent tqparent of the dialog widget
+ * \param parent parent of the dialog widget
* \param ok it will be set to true if the user pressed Ok after inserting a
* well-formatted angle